
# BackupRadar - Python API Wrapper

[![build + lint](https://github.com/cmathews393/backupradar-python/actions/workflows/build.yml/badge.svg)](https://github.com/cmathews393/backupradar-python/actions/workflows/build.yml) [![nightly](https://github.com/cmathews393/backupradar-python/actions/workflows/nightly.yml/badge.svg)](https://github.com/cmathews393/backupradar-python/actions/workflows/nightly.yml) [![publish](https://github.com/cmathews393/backupradar-python/actions/workflows/publish.yml/badge.svg)](https://github.com/cmathews393/backupradar-python/actions/workflows/publish.yml)
[![ruff](https://github.com/cmathews393/backupradar-python/actions/workflows/ruff.yml/badge.svg)](https://github.com/cmathews393/backupradar-python/actions/workflows/ruff.yml)

A simple wrapper for the BackupRadar API with some model definitions.
